#include <cstdio>
#include <cmath>
#include <vector>
#include <deque>
#include <algorithm>

using namespace std;
typedef long double ld;

#define FOREACH(iter, cont) for(__typeof((cont).begin()) iter = (cont).begin(); iter != (cont).end(); iter++)

const ld eps = 1e-6;

ld H[3][3];

class point3 {
  public:
    ld x, y, z;

    point3(ld xx = 0, ld yy = 0, ld zz = 0) {
      x = xx;
      y = yy;
      z = zz;
    }

    ld& operator[](int n) {
      switch (n) {
        case 0 : return x;
        case 1 : return y;
        default:
        return z;
      }
    }      
};

class point2 {
  public:
    ld x, y;

    point2(ld xx = 0, ld yy = 0) {
      x = xx;
      y = yy;
    }
};

point2 transform(point3& v) {
  ld y = 0;
  for (int j = 0; j < 3; j++)
    y += H[1][j]*v[j];
  ld z = 0;
  for (int j = 0; j < 3; j++)
    z += H[2][j]*v[j];

  return point2(y, z);
}

bool equals(ld x, ld y) {
  return fabs(x-y) < eps;
}

int operator<(const point2& a, const point2& b) {
  if (equals(a.x, b.x))
    return a.y < b.y;
  else
    return a.x < b.x;
}

const point2 operator-(const point2& a, const point2& b) {
  return point2(a.x-b.x, a.y-b.y);
}

ld operator*(const point2& a, const point2& b) {
  return a.x*b.y-a.y*b.x;
}

pair< vector<point2>, vector<point2> > convex_hull(vector<point2>& poly) {
 // printf("convex hull\n");
  // returns the bottom and top chains
  int n = poly.size();
  sort(poly.begin(), poly.end());
 // printf("after sort %d\n",n);

  vector<point2> top(n);
  top[0] = poly[0];
  int i = 1;
  int j = 0;
 // printf("YY\n");

  while (i < n) {
  //  printf("%d\n",i);
    if (j == 0 || (poly[i]-top[j])*(top[j-1]-top[j]) < 0)
      top[++j] = poly[i++];
    else
      j--;
  }
 // printf("xx\n");
  top.resize(j+1);
  vector<point2> :: iterator v = top.begin();
  while (v != top.end() && fabs(v->x - top.front().x) < eps)
    v++;
  top.erase(top.begin(), v-1);

// printf("top ok\n");
  vector<point2> bottom(n);
  bottom[0] = poly[0];
  i = 1;
  j = 0;

  while (i < n) {
    if (j == 0 || (poly[i]-bottom[j])*(bottom[j-1]-bottom[j]) > 0)
      bottom[++j] = poly[i++];
    else
      j--;
  }
  bottom.resize(j+1);
  v = bottom.end()-1;
  while (v != bottom.begin() && fabs(v->x - bottom.back().x) < eps)
    v--;
  bottom.erase(v+2, bottom.end());

  return make_pair(bottom, top);
}

ld getY(vector<point2> :: iterator i, ld x) {
  if (equals(i->x, x))
    return i->y;
  else {
    vector<point2> :: iterator j = i--;
    return (j->y - i->y)/(j->x - i->x)*(x - i->x) + i->y;
  }
}

int main() {
  int tests;
  for ( /*scanf("%d", &tests)*/ tests=1; tests; tests--) {

  vector<point3> ast1, ast2;
  point3 v1, v2;

  int m;
  for (scanf("%d", &m); m; m--) {
  //  printf("%d\n",m);
    ld x, y, z;
    scanf("%Lf %Lf %Lf", &x, &y, &z);
    ast1.push_back(point3(x, y, z));
  }
  scanf("%Lf %Lf %Lf", &v1.x, &v1.y, &v1.z);

  for (scanf("%d", &m); m; m--) {
    ld x, y, z;
    scanf("%Lf %Lf %Lf", &x, &y, &z);
    ast2.push_back(point3(x, y, z));
  }
  scanf("%Lf %Lf %Lf", &v2.x, &v2.y, &v2.z);
//   printf("NACITAL\n");
  point3 v(v1.x-v2.x, v1.y-v2.y, v1.z-v2.z);
  ld alf = sqrt(v.x*v.x + v.y*v.y + v.z*v.z);
  v.x -= alf;
  ld q = 2.0/(v.x*v.x + v.y*v.y + v.z*v.z);

  for (int i = 0; i < 3; i++)
    for (int j = 0; j < 3; j++)
      H[i][j] = (i == j) - q*v[i]*v[j];

  vector<point2> poly1, poly2;
  FOREACH(p, ast1) 
    poly1.push_back(transform(*p));
  FOREACH(p, ast2)
    poly2.push_back(transform(*p));
//  printf("T2\n");
/*
  int n = 3;
  srand(time(NULL));
  for(int i = 0; i < n; i++) {
    poly1.push_back(point2(rand() % 900 + 50, rand() % 600 + 50));
    poly2.push_back(point2(rand() % 900 + 50, rand() % 600 + 50));
  }
*/

  pair< vector<point2>, vector<point2> > r1 = convex_hull(poly1);
  pair< vector<point2>, vector<point2> > r2 = convex_hull(poly2);
 // printf("T2.5\n");
  ld start = (r1.first.front().x >? r2.first.front().x); 
  ld finish = (r1.first.back().x <? r2.first.back().x);
  vector<ld> x; // contains all the x coordinates
  FOREACH(p, r1.first)
    if (p->x >= start && p->x <= finish)
      x.push_back(p->x);
  FOREACH(p, r1.second)
    if (p->x >= start && p->x <= finish)
      x.push_back(p->x);
  FOREACH(p, r2.first)
    if (p->x >= start && p->x <= finish)
      x.push_back(p->x);
  FOREACH(p, r2.second)
    if (p->x >= start && p->x <= finish)
      x.push_back(p->x);

  sort(x.begin(), x.end());
  vector<ld> :: iterator new_end = unique(x.begin(), x.end(), equals);
  x.erase(new_end, x.end());
 // printf("T3\n");
  
  vector<ld> y[4];
  vector<point2> :: iterator it[4];
  it[0] = r1.first.begin();
  it[1] = r1.second.begin();
  it[2] = r2.first.begin();
  it[3] = r2.second.begin();


  for (int k = 0; k < 4; k++) {
    FOREACH(xx, x) {
      while (*xx-eps > it[k]->x)
        it[k]++;
      y[k].push_back(getY(it[k], *xx));
    }
  }

  bool intersect = false;
  for (unsigned int i = 0; i < x.size(); i++) {
//    printf("%d\n",i);
    if (equals(y[0][i], y[2][i])) {
      intersect = true;
      break;
    }

    if (y[0][i] < y[2][i] && y[1][i] > y[2][i]-eps) {
      intersect = true;
      break;
    }

    if (y[0][i] > y[2][i] && y[3][i] > y[0][i]-eps) {
      intersect = true;
      break;
    }
  }

  if (!intersect)
    for (unsigned int i = 1; i < x.size(); i++) 
      if ((y[0][i-1] < y[2][i-1]) ^ (y[0][i] < y[2][i])) {
        intersect = true;
        break;
      }

  printf(intersect ? "YES\n" : "NO\n");
  }

/*
  FILE *f;
  f = fopen("polygon.txt", "w");

  fprintf(f, "%d\n", x.size());
  for (unsigned int i = 0; i < x.size(); i++)
    fprintf(f, "%0.0lf\n", x[i]);

  for(int k = 0; k < 4; k++) {
    for (unsigned int i = 0; i < x.size(); i++)
      fprintf(f, "%0.0lf\n", y[k][i]);
  }

  fprintf(f, "%d\n", poly1.size());
  for (unsigned int i = 0; i < poly1.size(); i++)
    fprintf(f, "%0.0lf %0.0lf\n", poly1[i].x, poly1[i].y);

  fprintf(f, "%d\n", poly2.size());
  for (unsigned int i = 0; i < poly2.size(); i++)
    fprintf(f, "%0.0lf %0.0lf\n", poly2[i].x, poly2[i].y);

  fclose(f);
*/
}
